```
┌──┬──┐                 __    __          
│  │  │    ____  ____  / /_  / /___  _  __
├──┼──┤   / __ \/ __ \/ __ \/ / __ \| |/_/
│  │  │  / / / / /_/ / /_/ / / /_/ />  <  
└──┴──┘ /_/ /_/\____/_.___/_/\____/_/|_|
usage: noblox-cli.py [-h] {getenv,request,update,share,login} ...

noblox CLI tool.

positional arguments:
  {getenv,request,update,share,login}
                        Available commands
    getenv              Fetch environment variables and populate .env file
    request             Request API keys from fly.io or together.ai
    update              Check for updated API keys
    share               Share a restricted set of environment variables
    login               Login with an API key

options:
  -h, --help            show this help message and exit
```
